-- Lua code used by macros.forge_deprecated-srpm

local fedora = require "fedora.common"
local   auto = require "fedora.auto"

local function suffixes()
  return fedora.suffixes("forgeurl")
end

local function floop(f, index, otherargs)
  auto.floop(f, index, suffixes(), otherargs)
end

local changed = {
  ["forgeurl"]       = "forge_url",
  ["forgesource"]    = "forge_source",
  ["forgesetupargs"] = "forge_setup_arguments",
  ["shortcommit"]    = "forge_short_commit",
  ["extractdir"]     = "forge_extract_dir",
  ["topdir"]         = "forge_top_dir",
  ["archivename"]    = "forge_archive_name",
  ["archiveext"]     = "forge_archive_extension",
  ["archiveurl"]     = "forge_source",
  ["fileref"]        = "forge_file_ref"
}

local namespaced = {"scm", "ref", "tag", "commit", "version", "branch",
                    "owner", "repo", "namespace", "date"}

-- %forge_deprecated_init core
local function init(suffix, verbose)
  auto.id('forge_deprecated.init("' .. suffix .. '")')
  fedora.warning([[
Aliasing deprecated variable names to “forge_” variables. This aliasing will be
removed.]])
  local ismain = (suffix == "") or (suffix == "0")
  if ismain then
    olds = {}
    for old, _ in pairs(changed) do
      table.insert(olds, old)
    end
    fedora.zalias(olds, verbose)
    fedora.zalias(namespaced, verbose)
  end
  for old, new in pairs(changed) do
    fedora.safeset(new .. suffix, fedora.ref(old .. suffix), verbose)
  end
  fedora.alias(namespaced, "", suffix, "forge", suffix, verbose)
end

local function post_init(suffix, verbose)
  auto.id('forge_deprecated.post_init("' .. suffix .. '")')
  local ismain = (suffix == "") or (suffix == "0")
  for old, new in pairs(changed) do
    fedora.safeset(old .. suffix, fedora.ref(new .. suffix), verbose)
  end
  fedora.alias(namespaced, "forge", suffix, "", suffix, verbose)
  if ismain then
    olds = {}
    for old, _ in pairs(changed) do
      table.insert(olds, old)
    end
    fedora.zalias(olds, verbose)
    fedora.zalias(namespaced, verbose)
  end
end


return {
  floop     = floop,
  init      = init,
  post_init = post_init,
}
